==> glooxd-0.2.tar.bz2: glooxd-0.2/src/glooxd.cpp <==
/*
  Copyright (c) 2008-2009 by Jakob Schroeter <js@camaya.net>
  This file is part of the glooxd library. http://camaya.net/glooxd

  This software is distributed under a license. The full license
  agreement can be found in the file LICENSE in this distribution.
  This software may not be copied, modified, sold or distributed
  other than expressed in the named license agreement.

  This software is distributed without any warranty.
*/


#include "glooxd.h"

#include <gloox/error.h>
#include <gloox/iq.h>
#include <gloox/message.h>
#include <gloox/presence.h>
#include <gloox/tag.h>

namespace glooxd
{

  const std::string XMLNS_SERVER            = "jabber:server";
  const std::string XMLNS_GLOOXD            = "http://camaya.net/glooxd";

  const std::string XMPP_STREAM_VERSION_MAJOR = "1";
  const std::string XMPP_STREAM_VERSION_MINOR = "0";
  const std::string GLOOXD_VERSION            = "0.2";
  const std::string GLOOXD_DOMAIN             = "glooxd";

  gloox::Tag* returnError( const gloox::Tag* tag, gloox::StanzaError se )
  {
    gloox::Tag* t = 0;

    if( !tag )
      return t;

    const std::string& name = tag->name();
    const std::string& from = tag->findAttribute( "from" );
    const std::string& to = tag->hasAttribute( "to" ) ? tag->findAttribute( "to" ) : from;
    if( name == "message" )
    {
      gloox::Message msg( gloox::Message::Error, from );
      msg.setFrom( to );
      msg.addExtension( new gloox::Error( gloox::StanzaErrorTypeCancel, se ) );
      t = msg.tag();
    }
    else if( name == "iq" )
    {
      gloox::IQ iq( gloox::IQ::Error, from,
                    tag->findAttribute( "id" ) );
      iq.setFrom( to );
      iq.addExtension( new gloox::Error( gloox::StanzaErrorTypeCancel, gloox::StanzaErrorServiceUnavailable ) );
      t = iq.tag();
    }
    else if( name == "presence" )
    {
      gloox::Presence p(gloox::Presence::Error, from );
      p.setFrom( to );
      p.addExtension( new gloox::Error( gloox::StanzaErrorTypeCancel, gloox::StanzaErrorServiceUnavailable ) );
      t = p.tag();
    }

    return t;
  }

}

const char* glooxd_version()
{
  return glooxd::GLOOXD_VERSION.c_str();
}

==> glooxd-0.2.1.tar.bz2: glooxd-0.2.1/src/glooxd.cpp <==
/*
  Copyright (c) 2008-2009 by Jakob Schroeter <js@camaya.net>
  This file is part of the glooxd library. http://camaya.net/glooxd

  This software is distributed under a license. The full license
  agreement can be found in the file LICENSE in this distribution.
  This software may not be copied, modified, sold or distributed
  other than expressed in the named license agreement.

  This software is distributed without any warranty.
*/


#include "glooxd.h"

#include <gloox/error.h>
#include <gloox/iq.h>
#include <gloox/message.h>
#include <gloox/presence.h>
#include <gloox/tag.h>

namespace glooxd
{

  const std::string XMLNS_SERVER            = "jabber:server";
  const std::string XMLNS_GLOOXD            = "http://camaya.net/glooxd";

  const std::string XMPP_STREAM_VERSION_MAJOR = "1";
  const std::string XMPP_STREAM_VERSION_MINOR = "0";
  const std::string GLOOXD_VERSION            = "0.2.1";
  const std::string GLOOXD_DOMAIN             = "glooxd";

  gloox::Tag* returnError( const gloox::Tag* tag, gloox::StanzaError se )
  {
    gloox::Tag* t = 0;

    if( !tag )
      return t;

    const std::string& name = tag->name();
    const std::string& from = tag->findAttribute( "from" );
    const std::string& to = tag->hasAttribute( "to" ) ? tag->findAttribute( "to" ) : from;
    if( name == "message" )
    {
      gloox::Message msg( gloox::Message::Error, from );
      msg.setFrom( to );
      msg.addExtension( new gloox::Error( gloox::StanzaErrorTypeCancel, se ) );
      t = msg.tag();
    }
    else if( name == "iq" )
    {
      gloox::IQ iq( gloox::IQ::Error, from,
                    tag->findAttribute( "id" ) );
      iq.setFrom( to );
      iq.addExtension( new gloox::Error( gloox::StanzaErrorTypeCancel, gloox::StanzaErrorServiceUnavailable ) );
      t = iq.tag();
    }
    else if( name == "presence" )
    {
      gloox::Presence p(gloox::Presence::Error, from );
      p.setFrom( to );
      p.addExtension( new gloox::Error( gloox::StanzaErrorTypeCancel, gloox::StanzaErrorServiceUnavailable ) );
      t = p.tag();
    }

    return t;
  }

}

const char* glooxd_version()
{
  return glooxd::GLOOXD_VERSION.c_str();
}
